server_client_20150129_153949

### config2 : test_correctness

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 7.39964604378 sec | 10.6031210423 sec

Error message: Did not receive 3 in client1

Naarad report

### Metrics

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 17.53 | 17.53 | 17.53 | 17.53 | 17.53 | 17.53 | 17.53 | 17.53 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

#### client2-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 17.79 | 17.79 | 17.79 | 17.79 | 17.79 | 17.79 | 17.79 | 17.79 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.1095
server1-perf | latency | mean lt 0.33 | 0.11075
server1-perf | qps | mean lt 7.0 | 2.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 17.527
client1-perf | latency | mean lt 35.0 | 17.527
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | 17.791
client2-perf | latency | mean lt 35.0 | 17.791
client2-perf | qps | mean lt 2.0 | 1.0